# encoding: utf-8

# --------------------------------------------------------------------------------------------------
# (c) Copyright 2021 Micro Focus or one of its affiliates
#
# The only warranties for products and services of Micro Focus and its affiliates and licensors
# (Micro Focus) are as may be set forth in the express warranty statements accompanying such
# products and services. Nothing herein should be construed as constituting an additional
# warranty. Micro Focus shall not be liable for technical or editorial errors or omissions contained
# herein. The information contained herein is subject to change without notice.
# ---------------------------------------------------------------------------------------------------

# File:        channel_upgrade_congratulate
# Module:      Installation
# Summary:     ChannelUpgrade Congratulate Client
# Authors:     Gaurav Kumar <gaurav.kumar4@microfocus.com>
#
module Yast
  class ChannelUpgradeCongratulateClient < Client
    def main
      Yast.import "Pkg"
      Yast.import "UI"
      Yast.import "ProductControl"
      Yast.import "Wizard"
      Yast.import "Popup"
      Yast.import "GetInstArgs"
      Yast.import "Label"
      Yast.import "Wagon"

      textdomain "wagon"

      @ret = :auto

      @display = UI.GetDisplayInfo
      @space = Ops.get_boolean(@display, "TextMode", true) ? 1 : 3

      @caption = _("Online Migration Completed")


        @text = Builtins.sformat(
          _(
            "<p><b>Congratulations!</b><br>\n" +
              "The online migration has been completed.</p>\n" +
              "<p>The whole system has been upgraded.</p>\n" +
              "<p>Please visit us at %1.</p>\n" +
              "<p>Have a nice day!<br>\n"
          ),
          "https://www.microfocus.com/en-us/products/open-enterprise-server/overview "
        )

      @contents = VBox(
        VSpacing(@space),
        HBox(
          HSpacing(Ops.multiply(2, @space)),
          VBox(RichText(Id(:text), @text)),
          HSpacing(Ops.multiply(2, @space))
        ),
        VSpacing(@space),
        VSpacing(2)
      )

      @help = _(
        "<p><b>Abort</b> aborts the configuration of services and restarts the system.</p>\n" +
        "<p><b>Finish</b> completes the online migration.</p>\n"
      )

      Wizard.SetContents(
        @caption,
        @contents,
        @help,
        GetInstArgs.enable_back,
        GetInstArgs.enable_next
      )
      Wizard.SetTitleIcon("yast-license")

      Wizard.SetNextButton(:next, Label.FinishButton)
      Wizard.RestoreAbortButton
      Wizard.SetFocusToNextButton
      begin
        @ret = Convert.to_symbol(Wizard.UserInput)

        break if Popup.ConfirmAbort(:incomplete) if @ret == :abort
      end until @ret == :next || @ret == :back

      if @ret == :back
        Wizard.RestoreNextButton
      elsif @ret == :next
        Wizard.SetContents(
          @caption,
          Label(_("Finishing the migration...")),
          @help,
          GetInstArgs.enable_back,
          GetInstArgs.enable_next
        )

        Pkg.SourceSaveAll
        Pkg.TargetFinish

      end

      @ret
    end
  end
end

Yast::ChannelUpgradeCongratulateClient.new.main
