# encoding: utf-8

# -------------------------------------------------------------------------------
# (C) Copyright 2019 - 2021 Micro Focus or one of its affiliates.
#
# The only warranties for products and services of Micro Focus and its affiliates
# and licensors (“Micro Focus”) are as may be set forth in the express warranty
# statements accompanying such products and services. Nothing herein should be
# construed as constituting an additional warranty. Micro Focus shall not be
# liable for technical or editorial errors or omissions contained herein. The
# information contained herein is subject to change without notice.
#
# Except as specifically indicated otherwise, this document contains confidential
# information and a valid license is required for possession, use or copying. If
# this work is provided to the U.S. Government, consistent with FAR 12.211 and
# 12.212, Commercial Computer Software, Computer Software Documentation, and
# Technical Data for Commercial Items  are licensed to the U.S. Government under
# vendor's standard commercial license.
# -------------------------------------------------------------------------------

# File:
#	clients/wagon_congratulate.ycp
#
# Module:
#	Wagon
#
# Authors:
#	Lukas Ocilka <locilka@suse.cz>
#
# Summary:
#	Online Migration Tool
#
# $Id$
#
module Yast
  class WagonCongratulateClient < Client
    def main
      Yast.import "Pkg"
      Yast.import "UI"
      Yast.import "ProductControl"
      Yast.import "Wizard"
      Yast.import "Popup"
      Yast.import "GetInstArgs"
      Yast.import "Label"
      Yast.import "Wagon"

      textdomain "wagon"

      Wagon.RunHooks("before_congratulate")

      @ret = :auto

      @display = UI.GetDisplayInfo
      @space = Ops.get_boolean(@display, "TextMode", true) ? 1 : 3
      @timeout_message = _("The system will reboot now...")

      @caption = _("Migration Completed")

      @text = ProductControl.GetTranslatedText("migration_congratulate")

      if @text == nil || @text == ""
        Builtins.y2warning("Using fallback migration_congratulate text")
        # translators: %1 is a URL, e.g. http://www.suse.com
        @text = Builtins.sformat(
          _(
            "<p><b>Congratulations!</b><br>\n" +
              "You have upgraded the system.</p>\n" +
              "<p>You must reboot the system to complete the configuration of the OES services.</p>\n" +
              "<p>Click 'Reboot' to reboot the system.</p>\n"
          )
        )
      end

      @contents = VBox(
        VSpacing(@space),
        HBox(
          HSpacing(Ops.multiply(2, @space)),
          VBox(RichText(Id(:text), @text)),
          HSpacing(Ops.multiply(2, @space))
        ),
        VSpacing(@space),
        VSpacing(2)
      )

      @help = _(
        "<p><b>Back</b> displays the Customer Center Configuration page.</p>\n" +
        "<p><b>Abort</b> reverts the migration. The migration tool removes the temporary migration products " +
        "and installs the previously installed ones. By aborting the installation, you will have an " +
        "incomplete system that might or might not be usable. You might need to reinstall.</p>\n" +
        "<p><b>Reboot</b> reboots the system and completes the configuration of the OES services.</p>\n"
      )

      Wizard.SetContents(
        @caption,
        @contents,
        @help,
        GetInstArgs.enable_back,
        GetInstArgs.enable_next
      )
      Wizard.SetTitleIcon("yast-license")

      reboot_button = _("Reb&oot")
      Wizard.SetNextButton(:next, reboot_button)
      Wizard.RestoreAbortButton
      Wizard.SetFocusToNextButton
      begin
        @ret = Convert.to_symbol(Wizard.UserInput)

        break if Popup.ConfirmAbort(:incomplete) if @ret == :abort
      end until @ret == :next || @ret == :back

      if @ret == :back
        Wizard.RestoreNextButton
      elsif @ret == :next
        Wizard.SetContents(
          @caption,
          Label(_("Finishing the migration...")),
          @help,
          GetInstArgs.enable_back,
          GetInstArgs.enable_next
        )

        Pkg.SourceSaveAll
        Pkg.TargetFinish

        Wagon.RunHooks("after_congratulate")
        Popup.TimedLongMessage(@timeout_message, 10)
        cmd = Builtins.sformat("reboot")
        Builtins.y2milestone("Rebooting the system after wagon upgrade to load firstboot module")
        ret = Convert.to_map(SCR.Execute(path(".target.bash_output"), cmd))
      end

      @ret
    end
  end
end

Yast::WagonCongratulateClient.new.main
